# Android-specific information

The Glean SDK can be used in Android applications.
The integration into the build system for Android applications can be tuned to your needs.
See the following chapters for details.
